@@ -36,22 +36,51 @@ class Language(YrObject):
 
 class Location(YrObject):
 
-    def __init__(self, location_name, language=Language()):
+    def __init__(self, location_name, forecast_link='forecast', language=Language()):
         self.location_name = location_name
+        self.forecast_link = forecast_link
         self.language = language
         self.url = self.get_url()
         self.hash = self.get_hash()
 
     def get_url(self):
-        url = 'http://www.yr.no/{place}/{location_name}/{forecast}.xml'.format(
+        url = 'http://www.yr.no/{place}/{location_name}/{forecast_link}.xml'.format(
             location_name = urllib.parse.quote(self.location_name),
-            **self.language.dictionary # **self.language.dictionary contain ~> place + forecast
+            forecast_link = urllib.parse.quote(self.forecast_link),
+            **self.language.dictionary # **self.language.dictionary contain ~> place + forecast_link
         )
         return url
 
     def get_hash(self):
         return self.location_name.replace('/', '-')
 
+class LocationXYZ(YrObject):
+    """Class to use the API of yr.no"""
+
+    def __init__(self, x, y, z=0, language=Language()):
+        """
+        :param double x: longitude coordinate
+        :param double y: latitude coordinate
+        :param double z: altitude (meters above sea level)
+        :param language: a Language object
+        """
+        self.x = x
+        self.y = y
+        self.z = z
+        self.language = language
+        self.url = self.get_url()
+        self.hash = self.get_hash()
+
+    def get_url(self):
+        """Return the url of API service"""
+        url = "http://api.yr.no/weatherapi/locationforecast/1.9/?lat={y};" \
+              "lon={x};msl={z}".format(x=self.x, y=self.y, z=self.z)
+        return url
+
+    def get_hash(self):
+        """Create an hash with the three coordinates"""
+        return "location_{x}_{y}_{z}".format(x=self.x, y=self.y, z=self.z)
+
 class Connect(YrObject):
 
     def __init__(self, location):
@@ -103,4 +132,4 @@ class Cache(YrObject):
             return f.read()
 
 if __name__ == '__main__':
-    print(Connect(Location('Czech_Republic/Prague/Prague')).read())
+    print(Connect(Location(location_name='Czech_Republic/Prague/Prague')).read())
